Changelog
=========

- 0.5.4:
    - Fix copyrights in license
    - Add square icons for close buttons
    - Generate resources

- 0.5.3:
    - Add auto publishing release on successful build
    - Update docs url in setup.py

- 0.5.2:
    - Add auto release to PyPI after build
    - Ignore styles directory in Pylint

-  0.5.1:
    - Update PyPI docs
    - Update badges
    - Fix deploy workflow

-  0.5:
    -  Add build and docs workflows
    -  Add badges to README
    -  Add PyPI deploy workflow
    -  Create first QRainbowStyleSheet release
    -  Upload package to PyPI
    -  Update comments
    -  Update LICENSE and AUTHORS
    -  Update code of conduct version
    -  Remove PyQt4 and Pyside support
    -  Remove old api and deprecated code
    -  Remove Python 2.7 support
    -  Finish migrating docs to GitHub Pages

-  0.4:
    -  Add dependabot
    -  Add Windows and Darwin to tox platforms
    -  Fix preview images in docs
    -  Add auto generating docs on commit
    -  Move builds to Github Actions
    -  Remove Travis-CI config
    -  Remove pyside and pyqt4 from tox

-  0.3:
    -  Change qdarkstyle module name to qrainbowstyle
    -  Generate resources with new prefix

-  0.2:
    -  Add preview images
    -  Add frameless windows
    -  Add new example script
    -  Add NT and Darwin window buttons svg files
    -  Add svg to png generators for window buttons
    -  Update README
    -  Generate resources

-  **0.1**:
    -  Change project name
    -  Add stylesheet for QDial
    -  Add support for multiple styles
    -  Add new palettes: Oceanic, Cyberpunk, DarkOrange, LightOrange
    -  Apply https://github.com/ColinDuquesnoy/QDarkStyleSheet/pull/233
    -  Apply https://github.com/ColinDuquesnoy/QDarkStyleSheet/pull/241
    -  Removed old resources
    -  Generate resources for new styles
